ExceptionExplanationModel class

A model class for providing explanations for exceptions.

Constructors

ExceptionExplanationModel(String title, String content, String buttonContent)
Constructor for creating an ExceptionExplanationModel.

Properties

buttonContent String
The content for a button related to the exception explanation.
getter/setter pair
content String
The detailed content explaining the exception.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The title of the exception explanation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited